@@ -43,8 +43,8 @@ __all__ = ("main",)
 
 
 DEFAULT_RULES = {
-    "latexdep": {"command": "rr-latexdep $in"},
-    "bibtex": {"command": "rr-bibtex $in"},
+    "latexdep": {"command": "rr-latexdep $in", "depfile": "$in.d"},
+    "bibtex": {"command": "rr-bibtex $in", "depfile": "$in.d"},
     "latex": {"command": "rr-latex $in"},
     "copy": {"command": "cp $in $out"},
     "latexdiff": {"command": "latexdiff $in > $out"},
@@ -53,10 +53,7 @@ DEFAULT_RULES = {
     "svgtopdf": {
         "command": "inkscape $in --export-filename=$out --export-type=pdf; rr-normalize-pdf $out"
     },
-    "pythonscript": {
-        "command": "rr-python-script $in -- $args > $out",
-        "depfile": "$depfile",
-    },
+    "pythonscript": {"command": "rr-python-script $in -- $args > $out", "depfile": "$in.d"},
 }
 
 
@@ -68,11 +65,11 @@ def latex_pattern(path):
     prefix = result.group("prefix")
     workdir = f"latex-{prefix}"
 
-    def fixpath(local_path):
-        return os.path.normpath(os.path.join(workdir, local_path))
+    def fixpath(fn_local):
+        return os.path.normpath(os.path.join(workdir, fn_local))
 
     yield {
-        "outputs": fixpath(f"{prefix}.dd"),
+        "outputs": fixpath(f"{prefix}.tex.dd"),
         "implicit_outputs": [
             fixpath(f"{prefix}.aux"),
             fixpath(f"{prefix}.first.aux"),
@@ -92,8 +89,8 @@ def latex_pattern(path):
         "outputs": fixpath(f"{prefix}.pdf"),
         "rule": "latex",
         "inputs": fixpath(f"{prefix}.tex"),
-        "order_only": fixpath(f"{prefix}.dd"),
-        "dyndep": fixpath(f"{prefix}.dd"),
+        "order_only": fixpath(f"{prefix}.tex.dd"),
+        "dyndep": fixpath(f"{prefix}.tex.dd"),
     }
     yield {
         "outputs": os.path.join("uploads", f"{prefix}.pdf"),
@@ -119,8 +116,8 @@ def latexdiff_pattern(path):
     ext = result.group("ext")
     workdir = f"latex_{prefix}"
 
-    def fixpath(local_path):
-        return os.path.normpath(os.path.join(workdir, local_path))
+    def fixpath(fn_local):
+        return os.path.normpath(os.path.join(workdir, fn_local))
 
     yield {
         "outputs": fixpath(f"{prefix}-diff.{ext}"),
@@ -196,15 +193,14 @@ def python_script_pattern(path):
         else:
             build_cases = reprepbuild_cases()
 
-        def fixpath(local_path):
-            return os.path.normpath(os.path.join(workdir, local_path))
+        def fixpath(fn_local):
+            return os.path.normpath(os.path.join(workdir, fn_local))
 
         # Loop over all cases to make build records
         for script_args in build_cases:
             build_info = reprepbuild_info(*script_args)
             strargs = check_script_args(script_args)
             fn_log = fixpath(f"{prefix}{strargs}.log")
-            fn_depfile = fixpath(f"{prefix}{strargs}.depfile")
             yield {
                 "inputs": path,
                 "implicit": [fixpath(ipath) for ipath in build_info.get("inputs", [])],
@@ -214,7 +210,6 @@ def python_script_pattern(path):
                 "variables": {
                     "args": " ".join(str(arg) for arg in script_args),
                     "strargs": strargs,
-                    "depfile": fn_depfile,
                 },
                 "default": True,
             }
